#
# spec file for package python-scikit-sparse
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# For license file
%define tag     c94f8418b6c36c3ff9db4f87e00fc08bd51cfb4b
Name:           python-scikit-sparse
Version:        0.4.15
Release:        1.4
Summary:        Scikits sparse matrix package
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
URL:            https://github.com/scikit-sparse/scikit-sparse/
Source:         https://files.pythonhosted.org/packages/source/s/scikit-sparse/scikit_sparse-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy-devel >= 1.23.3}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module scipy >= 0.19}
BuildRequires:  %{python_module setuptools >= 18.0}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  suitesparse-devel
Requires:       python-numpy >= 1.23.3
Requires:       python-scipy >= 0.18
ExcludeArch:    %{ix86}
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Sparse matrix tools.

This is a sparse matrix code in Python that plays well with
scipy.sparse, but that is somehow unsuitable for inclusion in scipy
proper.

There is a wrapper for the CHOLMOD library for sparse Cholesky
decomposition.

%prep
%autosetup -p1 -n scikit_sparse-%{version}
# Move the test data to tests
mv sksparse/test_data tests

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pytest_arch -ra --pyargs tests

%files %{python_files}
%doc README.md
%license LICENSE.txt
%{python_sitearch}/sksparse
%{python_sitearch}/scikit_sparse-%{version}.dist-info

%changelog
* Mon Aug  5 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.4.15:
  * add publishing with a trusted publisher
  * Bump up numpy requirement
  * Autofind homebrew installation path
  * add publishing with a trusted publisher
  * Bump up numpy requirement
  * Autofind homebrew installation path
- Drop patch support-scipy-1.14.patch, included upstream.
- Move test_data under the tests directory and run tests there.
* Thu Jul 25 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.4.13:
  * Fix breaking changes in isspmatrix of scipy >=1.11.0, discontinuing
    compatibility with csc_array
  * remove numpy build restrictions
- Drop patches scikit-sparse-py312.patch, scipy111.patch:
  * Included upstream.
- Add patch support-scipy-1.14.patch:
  * Do not call a now removed method in scipy.
* Sun Feb 18 2024 Ben Greiner <code@bnavigator.de>
- Add scikit-sparse-py312.patch gh#scikit-sparse/scikit-sparse#105
* Fri Sep  8 2023 Matej Cepl <mcepl@suse.com>
- Clean up the SPEC file.
- Convert from python_{build,install} to
  pyproject_{wheel,install} macros.
* Thu Aug 31 2023 Markéta Machová <mmachova@suse.com>
- Update to 0.4.12
  * Allow suitesparse include/library paths to be passed in to
    pip install through environment variables.
  * Added support for python 3.11
  * Fix compilation with Cython>=3.0.0
- Add upstream scipy111.patch
* Sat Apr 24 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.4.5
  * Use PEP-517 style build-system so numpy and cython are no longer
    needed prior to installation (openSUSE: we still use
    setuptools here)
  * Added support for python 3.9
- Remove nose -- gh#scikit-sparse/pull#66
* Fri Feb 12 2021 Dirk Müller <dmueller@suse.com>
- skip python 36 build
* Wed Nov  7 2018 mcepl@suse.com
- Update to 0.4.4:
  * Bug in solve with dense array, where base of result is not
    set correctly, fixed.
  * Supported versions updated to: - Python: 3.7, 3.6 - NumPy:
    1.15, 1.14, 1.13 - SciPy: 1.1, 1.0, 0.19 - SuiteSparse: 5.2
* Wed Aug  8 2018 jengelh@inai.de
- Trim irrelevant parts from description.
* Thu May 24 2018 toddrme2178@gmail.com
- Add license file
- spec file cleanups
* Thu Apr 19 2018 toddrme2178@gmail.com
- Update to version 0.4.3
  * The method solve_L can now also use the L matrix of the LL' decomposition.
  * Supported versions updated to Python 3.6, 3.5 and 2.7, NumPy 1.14 and 1.13 and SciPy 1.0 and 0.19.
* Thu May 25 2017 toddrme2178@gmail.com
- Initial version
